@@ -15,7 +15,7 @@ def _get_version(v):
 def get_build():
     total = ''
     a = time.localtime(time.time())
-    total += str(a.tm_year)
+    total += str(a.tm_year)[2:]
     total += str(a.tm_mon)
     total += str(a.tm_mday)
     total += str(a.tm_hour)
